anesthetic package
==================

Subpackages
-----------

.. toctree::

    anesthetic.gui
    anesthetic.read

Submodules
----------

anesthetic.kde module
---------------------

.. automodule:: anesthetic.kde
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.plot module
----------------------

.. automodule:: anesthetic.plot
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.samples module
-------------------------

.. automodule:: anesthetic.samples
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.utils module
-----------------------

.. automodule:: anesthetic.utils
    :members:
    :undoc-members:
    :show-inheritance:

anesthetic.weighted\_pandas module
----------------------------------

.. automodule:: anesthetic.weighted_pandas
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: anesthetic
    :members:
    :undoc-members:
    :show-inheritance:
